/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.social.entity;

import com.alibaba.excel.annotation.ExcelProperty;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttribute;
import com.yifu.cloud.plus.v1.yifu.common.mybatis.base.BaseEntity;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;

/**
 * 社保自动化审核提交后的审核结果查询记录表
 *
 * @author hgw
 * @date 2024-05-23 17:40:37
 */
@Data
@TableName("t_social_auto_audit_task")
@EqualsAndHashCode(callSuper = true)
@Schema(description = "社保自动化审核提交后的审核结果查询记录表")
public class TSocialAutoAuditTask extends BaseEntity {

	/**
	 * id
	 */
	@TableId(type = IdType.ASSIGN_ID)
	@ExcelProperty("id")
	@Schema(description = "id")
	private String id;
	/**
	 * 审核查询的任务ID
	 */
	@ExcelAttribute(name = "审核查询的任务ID", isNotEmpty = true, errorInfo = "审核查询的任务ID不能为空", maxLength = 32)
	@NotBlank(message = "审核查询的任务ID不能为空")
	@Length(max = 32, message = "审核查询的任务ID不能超过32个字符")
	@ExcelProperty("审核查询的任务ID")
	@Schema(description = "审核查询的任务ID")
	private String auditId;
	/**
	 * 1养工失；2医生大
	 */
	@ExcelAttribute(name = "1养工失；2医生大", isNotEmpty = true, errorInfo = "1养工失；2医生大不能为空", maxLength = 1)
	@NotBlank(message = "1养工失；2医生大不能为空")
	@Length(max = 1, message = "1养工失；2医生大不能超过1个字符")
	@ExcelProperty("1养工失；2医生大")
	@Schema(description = "1养工失；2医生大")
	private String type;

}
